==> notion_api-0.3.8.tar.gz: notion_api-0.3.8/notion/__init__.py <==
# MIT License

# Copyright (c) 2023 ayvi-0001

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
""" 
### Properties:
>>> from notion import properties as prop

### Queries:
>>> from notion import query
query objects:
 - SortFilter
 - PropertyFilter
 - CompoundFilter
 - TimestampFilter
 - EntryTimestampSort
 - PropertyValueSort

To combine a CompoundFilter/PropertyFilter with a SortFilter, use `notion.build_payload(...)`
"""
from typing import Sequence

import notion.properties as properties
import notion.query as query
from notion.api import Block, BlockFactory, Database, Page, Workspace
from notion.api._pkgv import inspect_pkg_version
from notion.properties.build import build_payload

__all__: Sequence[str] = (
    "Page",
    "Database",
    "Block",
    "Workspace",
    "BlockFactory",
    "build_payload",
    "properties",
    "query",
    "inspect_pkg_version",
)

==> notion_api-0.3.9.tar.gz: notion_api-0.3.9/notion/__init__.py <==
# MIT License

# Copyright (c) 2023 ayvi-0001

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
""" 
### Properties:
>>> from notion import properties as prop

### Queries:
>>> from notion import query
query objects:
 - SortFilter[PropertyValueSort | EntryTimestampSort]
 - CompoundFilter[CompoundFilter | PropertyFilter | TimestampFilter]
 - PropertyFilter
 - TimestampFilter
"""
from typing import Sequence

import notion.properties as properties
import notion.query as query
from notion.api import Block, BlockFactory, Database, Page, Workspace
from notion.api._pkgv import inspect_pkg_version
from notion.properties.build import build_payload

__all__: Sequence[str] = (
    "Page",
    "Database",
    "Block",
    "Workspace",
    "BlockFactory",
    "build_payload",
    "properties",
    "query",
    "inspect_pkg_version",
)
